@@ -9,8 +9,10 @@ import shutil
 import stat
 import yaml
 
-from ._validation_util import _validate_confirmation_inputs
-from .pretty_print import console_log, print_table, task_processing
+from munchie.util import (
+    _rich_util,
+    _validation_util
+)
 from datetime import datetime
 from json.decoder import JSONDecodeError
 from pathlib import Path
@@ -35,6 +37,8 @@ class FileMuncher:
     Functions:
         create_new_directory: create a new directory
         create_new_file: create a new file
+        get_directory_contents: get the immediate contents of a directory or all the contents directory recusively
+        get_path_stats: get the filesystem details of a directory or a file path
         read_file: read in a file and get the contents
         remove_directory: remove a directory and all of its contents
         remove_file: remove a file
@@ -61,7 +65,7 @@ class FileMuncher:
             path_to_convert (str): path to file or directory
 
         Returns:
-            path_to_convert (Path): provided path converted to Path type
+            (Path): provided path converted to Path type
         """
 
         if isinstance(path_to_convert, str):         # if the path is a string type
@@ -84,7 +88,7 @@ class FileMuncher:
             path_to_file (Path): path the the file to get the extension for
 
         Returns:
-            file_extension (str): extension of the file
+            (str): extension of the file
 
         Raises:
             AttributeError: file path has no extension specified
@@ -123,7 +127,7 @@ class FileMuncher:
             id_type (str): the type of id to resolve. user or group
 
         Returns:
-            owner_name (str): the translated owner id. if the platform is Windows then the uid will be returned back
+            (str): the translated owner id. if the platform is Windows then the uid will be returned back
         """
 
         if platform.system() == 'Windows':                               # if running on a Windows machine
@@ -154,7 +158,7 @@ class FileMuncher:
                     no_headers: set to True if the csv does not have headers
 
         Returns:
-            contents (list): default is list of dictionaries
+            (list): default is list of dictionaries
                 (list of dicts) returns list of dictionaries if no_headers option is not set or is False
                 (list of lists) return list of lists if no_headers option is set to True
 
@@ -200,7 +204,7 @@ class FileMuncher:
             path_to_file (Path | str): path to ini file
 
         Returns:
-            contents (dict): ini contents read in as a dictionary
+            (dict): ini contents read in as a dictionary
         """
 
         config = configparser.ConfigParser()               # define config object
@@ -226,7 +230,7 @@ class FileMuncher:
             path_to_file (Path | str): path to json file
 
         Returns:
-            contents (dict): json contents read in as a dictionary
+            (dict): json contents read in as a dictionary
 
         Raises:
             JSONDecodeError: invalid JSON format
@@ -251,7 +255,7 @@ class FileMuncher:
             path_to_file (Path | str): path to txt file
 
         Returns:
-            contents (dict): list of strings
+            (dict): list of strings
         """
 
         with open(path_to_file, 'r') as infile:                 # open the file
@@ -270,7 +274,7 @@ class FileMuncher:
             path_to_file (Path | str): path to yaml file
 
         Returns:
-            contents (dict): yaml contents read in as a dictionary
+            (dict): yaml contents read in as a dictionary
         """
 
         try:
@@ -495,7 +499,7 @@ class FileMuncher:
             recursive (bool): set to True to recursively list all contents of each directory in and under the given path; defaults to False
 
         Returns:
-            directory_contents (dict): dictionary of the folders and files
+            (dict): dictionary of the folders and files
         """
 
         path_to_directory = self._convert_path_type(path_to_directory)                  # normalize the path
@@ -537,7 +541,7 @@ class FileMuncher:
             timezone (str): specific timezone for date and timestamps; default is UTC
 
         Returns:
-            path_details (dict): file system details about the path provided
+            (dict): file system details about the path provided
                 {
                     type: file or directory
                     st_mode: read|write|execute permissions
@@ -635,11 +639,11 @@ class FileMuncher:
                 while isinstance(confirmation, type(None)):                   # loop until confirmation is not None
                     # prompt for user input
                     user_input = input(f"Remove '{dir_to_rm}' and all of its contents? (q to quit) [y/n]: ")
-                    confirmation = _validate_confirmation_inputs(user_input)                  # validate the user input
+                    confirmation = _validation_util._validate_confirmation_inputs(user_input)            # validate the user input
 
-            if force or confirmation:                                                         # if force flag exists or confirmation is True
-                shutil.rmtree(dir_to_rm)                                                      # remove the directory
-                console_log(f"Remove directory: '{dir_to_rm}' successful.", 'informational')  # print the deletion to the console
+            if force or confirmation:                                                                    # if force flag exists or confirmation is True
+                shutil.rmtree(dir_to_rm)                                                                 # remove the directory
+                _rich_util.console_log(f"Remove directory: '{dir_to_rm}' successful.", 'informational')  # print the deletion to the console
 
     def remove_file(self: 'FileMuncher', file_to_rm: Union['Path', str], force: bool = False) -> None:
         """
@@ -660,11 +664,11 @@ class FileMuncher:
             if not force:                                                                 # check for force flag
                 while isinstance(confirmation, type(None)):                               # loop until confirmation is not None
                     user_input = input(f"Remove '{file_to_rm}'? (q to quit) [y/n]: ")     # prompt for user input
-                    confirmation = _validate_confirmation_inputs(user_input)              # validate the user input
+                    confirmation = _validation_util._validate_confirmation_inputs(user_input)  # validate the user input
 
-            if force or confirmation:                                                     # if force flag exists or confirmation is True
-                os.remove(file_to_rm)                                                     # remove the file
-                console_log(f"Remove file: '{file_to_rm}' successful.", 'informational')  # print the deletion to the console
+            if force or confirmation:                                                                # if force flag exists or confirmation is True
+                os.remove(file_to_rm)                                                                # remove the file
+                _rich_util.console_log(f"Remove file: '{file_to_rm}' successful.", 'informational')  # print the deletion to the console
 
     def rotate_files(self, directory_to_clean: Union['Path', str], days_old: int = 14, force: bool = False) -> None:
         """
@@ -702,23 +706,23 @@ class FileMuncher:
         if len(all_files_to_remove) > 0:                                                  # if old files were found
             confirmation = None                                                           # place holder for confirmation
             if not force:                                                                 # check for force flag
-                console_log('-- FILES TO REMOVE --', 'warning')                           # print header to connsole
-                console_log(f'Source path: {directory_to_clean}')                         # print source path to console
+                _rich_util.console_log('-- FILES TO REMOVE --', 'warning')                # print header to connsole
+                _rich_util.console_log(f'Source path: {directory_to_clean}')              # print source path to console
                 # print the files to remove as a table
-                print_table(sorted(all_files_to_remove, reverse=True), ['File Name', 'Last Modified Date'], len(all_files_to_remove))
+                _rich_util.print_table(sorted(all_files_to_remove, reverse=True), ['File Name', 'Last Modified Date'], len(all_files_to_remove))
 
                 while isinstance(confirmation, type(None)):                                     # loop until confirmation is not None
                     user_input = input('The above files will be removed. Continue? [y/n] (q to quit): ')  # prompt for user input
-                    confirmation = _validate_confirmation_inputs(user_input)                    # validate the user input
+                    confirmation = _validation_util._validate_confirmation_inputs(user_input)             # validate the user input
 
             elif force or confirmation:                                                         # if force flag exists or confirmation is True
-                while task_processing('Cleaning up old files'):                                 # show processing spinner and message
+                while _rich_util.task_processing('Cleaning up old files'):                      # show processing spinner and message
                     for old_file in all_files_to_remove:                                        # begin loop over each file to delete
                         self.remove_file(Path.joinpath(directory_to_clean, old_file[0]), True)  # delete the old file
                     break                                                                       # break the loop and stop the spinner
 
         else:
-            console_log(f'No files older than {days_old} days old found. Nothing to remove.', 'informational')
+            _rich_util.console_log(f'No files older than {days_old} days old found. Nothing to remove.', 'informational')
 
     def update_path(self, attribute_name: str, attribute_path: Union['Path', str], is_dir: bool = False, is_file: bool = False) -> Union[None, NoReturn]:
         """
@@ -789,7 +793,7 @@ def create_global_files_object() -> 'FileMuncher':
     Instantiate a global Files object.
 
     Returns:
-        FILES_OBJ (Files): instantiated Files object
+        (Files): instantiated Files object
     """
 
     global FILES_OBJ           # declare the global
@@ -803,7 +807,7 @@ def get_global_files_object() -> 'FileMuncher':
     Get the global Files object without instantiating a new instance.
 
     Returns:
-        FILES_OBJ (Files): instantiated Files object
+        (Files): instantiated Files object
 
     Raises:
         NameError: raised if FILES_OBJ has not been created
